import logging

from .platform.distro import Distro
from .util import run_op, has_program

logger = logging.getLogger(__name__)

class AptInterface:

    def __init__(self):
        pass 

    def update(self):
        op = "apt-get update"
        logger.info(f"Updating apt: {op}")
        run_op(op)

    def upgrade(self):
        op = "apt-get -y upgrade"
        logger.info(f"Upgrading via apt: {op}")
        run_op(op)

    def install_packages(self, packages: list):
        packages_str = " ".join(packages)
        op = f"apt-get install -y {packages_str}"
        logger.info(f"Installing packages: {op}")
        run_op(op)

class SystemPackage:

    def __init__(self, name):
        self.name = name
        self.package_alt_names = {}

    def check_available(self):
        if has_program(self.name):
            return

        msg = f"Program {self.name} not found"
        if Distro.has_apt():
            msg = f"Program not found. Install with: sudo apt-get install {self.name}"
        raise RuntimeError(msg)
        

class PackageManager:

    def __init__(self):
        self.apt = AptInterface()

    def update(self):
        self.apt.update()

    def upgrade(self):
        self.update()
        self.apt.upgrade()

    def install_packages(self, packages: list):
        self.apt.install_packages(packages)
